#!/bin/bash
#

extraqual=${1}
basequal=gcc47
pkgver=v2_1
pkgdotver=2.1
gccver=v4_7_1
gccdotver=4.7

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG"
    extra_command="-DCMAKE_BUILD_TYPE=Release"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    # default debug CFLAGS are -g
    cxxflg="-g -O0"
    extra_command="-DCMAKE_BUILD_TYPE=Debug"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
    extra_command="-DCMAKE_BUILD_TYPE=MinSizeRel"
else
   echo "ERROR: please define the extra qualifier"
   echo "USAGE: buildSzip.sh <opt|debug|prof>"
   exit 1
fi

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
pkgdir=${PRODUCTS}/szip/${pkgver}/${flvr}-${qualdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc
setup gcc ${gccver}
gccshortver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccshortver} = ${gccdotver} ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${pkgdir}/build
if [ ! -d ${pkgdir}/build ]
then
   echo "ERROR: failed to create ${pkgdir}/build"
   exit 1
fi
cd ${pkgdir}/build

setup cmake

set -x

cd ${pkgdir}/build
cmake -DCMAKE_INSTALL_PREFIX=${pkgdir} ${extra_command}  ${PRODUCTS}/szip/${pkgver}/source/szip-${pkgdotver}
make 
make install 

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
   echo "Finished building szip for flavor ${flvr}"
   echo "Declaring szip ${pkgver} for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare szip ${pkgver} -r szip/${pkgver} -2 -m szip.table -q ${fullqual}
else 
   ups declare szip ${pkgver} -r szip/${pkgver} -4 -m szip.table -q ${fullqual}
fi
setup szip ${pkgver} -q ${fullqual}
echo "szip headers are installed in ${SZIP_INC}"

exit 0
